@@ -3,7 +3,9 @@ About Dialog Box class for PyGPSClient application.
 
 Created on 20 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 
 from tkinter import Toplevel, Label, Button
@@ -25,7 +27,7 @@ class AboutDialog:
         """
         Initialise Toplevel dialog
 
-        :param app: reference to main tkinter application
+        :param Frame app: reference to main tkinter application
         """
 
         self.__app = app  # Reference to main application class
