@@ -1,8 +1,11 @@
 """
-PyGPSClient - Main tkinter application class
+PyGPSClient - Main tkinter application class.
 
 Created on 12 Sep 2020
-@author: semuadmin
+
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 
 from threading import Thread
@@ -44,14 +47,16 @@ VERSION = __version__
 
 class App(Frame):  # pylint: disable=too-many-ancestors
     """
-    Main GUI Application Class
+    Main PyGPSClient GUI Application Class
     """
 
     def __init__(self, master, *args, **kwargs):
         """
         Set up main application and add frames
 
-        :param object master: reference to Tk instance
+        :param tkinter.Tk master: reference to Tk root
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__master = master
@@ -274,6 +279,7 @@ class App(Frame):  # pylint: disable=too-many-ancestors
 
         :param str message: message to be displayed in connection label
         :param str color: rgb color string
+
         """
 
         self.frm_status.set_connection(message, color)
@@ -284,6 +290,7 @@ class App(Frame):  # pylint: disable=too-many-ancestors
 
         :param str message: message to be displayed in status label
         :param str color: rgb color string
+
         """
 
         self.frm_status.set_status(message, color)
@@ -321,6 +328,8 @@ class App(Frame):  # pylint: disable=too-many-ancestors
     def get_master(self):
         """
         Returns application master (Tk)
+
+        :return: reference to application master (Tk)
         """
 
         return self.__master
