@@ -5,7 +5,9 @@ This handles the top banner which prominently displays the current coordinates a
 
 Created on 13 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
 
@@ -48,7 +50,9 @@ class BannerFrame(Frame):
         """
         Constructor.
 
-        :param app: reference to main tkinter application
+        :param Frame app: reference to main tkinter application
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__app = app  # Reference to main application class
@@ -290,7 +294,7 @@ class BannerFrame(Frame):
         """
         Sets text of banner from keyword parms.
 
-        :param kwargs: optional key value pairs
+        :param kwargs: optional key value pairs for each displayed parameter
         """
 
         settings = self.__app.frm_settings.get_settings()
@@ -363,7 +367,7 @@ class BannerFrame(Frame):
         Update track and ground speed
 
         :param str units: distance units as string (UMM, UMK, UI, UIK)
-        :param kwargs: optional key value pairs
+        :param kwargs: optional speed and/or track key/value pairs
         """
 
         if "speed" in kwargs:
@@ -395,7 +399,7 @@ class BannerFrame(Frame):
         """
         Update fix type
 
-        :param kwargs: optional key value pairs
+        :param kwargs: optional fix key/value pair
         """
 
         if "fix" in kwargs:
@@ -495,7 +499,7 @@ class BannerFrame(Frame):
         """
         Resize frame
 
-        :param event:
+        :param event event: resize event
         """
 
         self.width, self.height = self.get_size()
@@ -504,6 +508,9 @@ class BannerFrame(Frame):
     def get_size(self):
         """
         Get current frame size.
+
+        :return: window size (width, height)
+        :rtype: tuple
         """
 
         self.update_idletasks()  # Make sure we know about any resizing
