@@ -5,7 +5,9 @@ This handles a scrollable text box into which the serial data is printed.
 
 Created on 12 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
 
@@ -23,7 +25,9 @@ class ConsoleFrame(Frame):
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
+        :param Frame app: reference to main tkinter application
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__app = app  # Reference to main application class
@@ -87,7 +91,8 @@ class ConsoleFrame(Frame):
         'maxlines' defines the maximum number of scrollable lines that are
         retained in the text box on a FIFO basis.
 
-        :param str data
+        :param str data: data from input stream
+
         """
 
         settings = self.__app.frm_settings.get_settings()
@@ -112,8 +117,9 @@ class ConsoleFrame(Frame):
         Highlights any occurrence of tags in line - each tag
         must be a tuple of (search term, highlight color)
 
-        :param str line
+        :param str line: line in console
         :param tuple tags: (search term, highlight color)
+
         """
 
         con = self.txt_console
@@ -133,7 +139,7 @@ class ConsoleFrame(Frame):
         """
         Resize frame
 
-        :param event
+        :param event event: resize event
         """
 
         self.width, self.height = self.get_size()
@@ -141,6 +147,9 @@ class ConsoleFrame(Frame):
     def get_size(self):
         """
         Get current object size.
+
+        :return: window size (width, height)
+        :rtype: tuple
         """
 
         self.update_idletasks()  # Make sure we know about any resizing
