@@ -5,7 +5,9 @@ This handles a frame containing a graph of current satellite reception.
 
 Created on 14 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
 
@@ -31,7 +33,9 @@ class GraphviewFrame(Frame):
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
+        :param Frame app: reference to main tkinter application
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__app = app  # Reference to main application class
@@ -121,7 +125,7 @@ class GraphviewFrame(Frame):
         Automatically adjust y axis according to number of satellites in view.
 
         :param list data: array of satellite tuples (gnssId, svid, elev, azim, cno):
-        :param int siv: number of satellites in view
+        :param int siv: number of satellites in view (default = 16)
         """
 
         if siv == 0:
@@ -166,6 +170,8 @@ class GraphviewFrame(Frame):
     def _on_resize(self, event):  # pylint: disable=unused-argument
         """
         Resize frame
+
+        :param event event: resize event
         """
 
         self.width, self.height = self.get_size()
@@ -173,6 +179,9 @@ class GraphviewFrame(Frame):
     def get_size(self):
         """
         Get current canvas size.
+
+        :return: window size (width, height)
+        :rtype: tuple
         """
 
         self.update_idletasks()  # Make sure we know about any resizing
