@@ -6,25 +6,23 @@ the appropriate protocol handler
 
 Created on 16 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 
 from io import BufferedReader
 from threading import Thread
-
 from serial import Serial, SerialException, SerialTimeoutException
-
 import pyubx2.ubxtypes_core as ubt
 
 from .globals import (
     CONNECTED,
     CONNECTED_FILE,
     DISCONNECTED,
-    SERIAL_TIMEOUT,
     NMEA_PROTOCOL,
     MIXED_PROTOCOL,
     UBX_PROTOCOL,
-    PARITIES,
 )
 from .strings import STOPDATA, NOTCONN, SEROPENERROR, ENDOFFILE
 
@@ -38,7 +36,8 @@ class SerialHandler:
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
+        :param Frame app: reference to main tkinter application
+
         """
 
         self.__app = app  # Reference to main application class
@@ -77,9 +76,10 @@ class SerialHandler:
         baudrate = settings["baudrate"]
         databits = settings["databits"]
         stopbits = settings["stopbits"]
-        parity = PARITIES[settings["parity"]]
+        parity = settings["parity"]
         xonxoff = settings["xonxoff"]
         rtscts = settings["rtscts"]
+        timeout = settings["timeout"]
         self._datalogging = settings["datalogging"]
         self._recordtrack = settings["recordtrack"]
 
@@ -92,7 +92,7 @@ class SerialHandler:
                 parity=parity,
                 xonxoff=xonxoff,
                 rtscts=rtscts,
-                timeout=SERIAL_TIMEOUT,
+                timeout=timeout,
             )
             self._serial_buffer = BufferedReader(self._serial_object)
             self.__app.frm_banner.update_conn_status(CONNECTED)
@@ -216,7 +216,7 @@ class SerialHandler:
         """
         Write binary data to serial port.
 
-        :param bytes data
+        :param bytes data: data to write to stream
         """
 
         try:
@@ -300,7 +300,7 @@ class SerialHandler:
         """
         Action on <<ubx_read>> event - read any data in the buffer.
 
-        :param event
+        :param event event: read event
         """
 
         #         print("doing serial_handler.on_read")
@@ -314,7 +314,7 @@ class SerialHandler:
         """
         Action on end of file
 
-        :param event
+        :param event event: eof event
         """
 
         #         print("doing serial_handler.on_eof")
