@@ -5,7 +5,9 @@ This handles the settings/configuration panel.
 
 Created on 12 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors, unnecessary-lambda
 
@@ -51,6 +53,7 @@ from .globals import (
     UBX_PROTOCOL,
     MIXED_PROTOCOL,
     KNOWNGPS,
+    BAUDRATES,
 )
 from .strings import (
     LBLUBXCONFIG,
@@ -62,6 +65,18 @@ from .strings import (
     LBLLEGEND,
 )
 
+TIMEOUTS = (
+    "0.2",
+    "1",
+    "2",
+    "5",
+    "10",
+    "20",
+    "None",
+    "0",
+    "0.1",
+)
+
 
 class SettingsFrame(Frame):
     """
@@ -72,7 +87,9 @@ class SettingsFrame(Frame):
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
+        :param Frame app: reference to main tkinter application
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__app = app  # Reference to main application class
@@ -116,7 +133,9 @@ class SettingsFrame(Frame):
         self.option_add("*Font", self.__app.font_sm)
 
         # serial port configuration panel
-        self._frm_serial = SerialConfigFrame(self, preselect=KNOWNGPS)
+        self._frm_serial = SerialConfigFrame(
+            self, preselect=KNOWNGPS, timeouts=TIMEOUTS, baudrates=BAUDRATES
+        )
 
         # connection buttons
         self._frm_buttons = Frame(self)
@@ -380,6 +399,7 @@ class SettingsFrame(Frame):
         depending on connection status.
 
         :param int status: connection status as integer (0,1,2)
+
         """
 
         self._frm_serial.set_controls(status)
@@ -423,8 +443,9 @@ class SettingsFrame(Frame):
         """
         Public method returns all settings as a dict.
 
-        :return current settings
-        :rtype dict
+        :return: current settings
+        :rtype: dict
+
         """
 
         self._settings["noports"] = self._frm_serial.noports
@@ -436,6 +457,7 @@ class SettingsFrame(Frame):
         self._settings["parity"] = self._frm_serial.parity
         self._settings["rtscts"] = self._frm_serial.rtscts
         self._settings["xonxoff"] = self._frm_serial.xonxoff
+        self._settings["timeout"] = self._frm_serial.timeout
 
         self._settings["protocol"] = self._protocol.get()
         self._settings["raw"] = self._raw.get()
@@ -457,8 +479,9 @@ class SettingsFrame(Frame):
         """
         Get current frame size.
 
-        :return (width, height)
-        :rtype tuple
+        :return: (width, height)
+        :rtype: tuple
+
         """
 
         self.update_idletasks()  # Make sure we know about any resizing
