@@ -5,12 +5,14 @@ Uses pyubx2 library for parsing
 
 Created on 30 Sep 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name
 
 from datetime import datetime
-from pyubx2 import UBXMessage, UBX_MSGIDS
+from pyubx2 import UBXMessage, UBXReader, UBX_MSGIDS
 from pyubx2.ubxhelpers import itow2utc, gpsfix2str
 from .globals import svid2gnssid, GLONASS_NMEA
 
@@ -28,7 +30,7 @@ class UBXHandler:
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
+        :param Frame app: reference to main tkinter application
         """
 
         self.__app = app  # Reference to main application class
@@ -66,11 +68,11 @@ class UBXHandler:
         Process UBX message type
 
         :param bytes data: raw data
-        :return UBXMessage:
+        :return: UBXMessage
         :rtype: UBXMessage
         """
 
-        parsed_data = UBXMessage.parse(data, False)
+        parsed_data = UBXReader.parse(data, False)
 
         if parsed_data.identity == "ACK-ACK":
             self._process_ACK_ACK(parsed_data)
