@@ -3,7 +3,9 @@ UBX Configuration widget for CFG-PRT commands
 
 Created on 22 Dec 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
 
@@ -47,8 +49,10 @@ class UBX_PORT_Frame(Frame):
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
-        :param frame container: container frame
+        :param Frame app: reference to main tkinter application
+        :param Frame container: reference to container frame (config-dialog)
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__app = app  # Reference to main application class
@@ -191,6 +195,9 @@ class UBX_PORT_Frame(Frame):
     def update_status(self, cfgtype, **kwargs):
         """
         Update pending confirmation status.
+
+        :param str cfgtype: identity of UBX message containing config info
+        :param kwargs: status keywords and values from UBX config message
         """
 
         if cfgtype == "CFG-PRT":
